# This package contains macros that provide functionality relating to
# Software Collections. These macros are not used in default
# Fedora builds, and should not be blindly copied or enabled.
# Specifically, the "scl" macro must not be defined in official Fedora
# builds. For more information, see:
# http://docs.fedoraproject.org/en-US/Fedora_Contributor_Documentation/1/html/Software_Collections_Guide/index.html

%{?scl:%scl_package rubygem-%{gem_name}}
%{!?scl:%global pkg_name %{name}}

%global gem_name foreman_openscap

%define rubyabi 1.9.1
%global foreman_dir /usr/share/foreman
%global foreman_bundlerd_dir %{foreman_dir}/bundler.d

Name: %{?scl_prefix}rubygem-%{gem_name}
Version: 0.3.2.10
Release: 1%{?dist}
Summary: Foreman plug-in for displaying OpenSCAP audit reports
Group: Applications/System
License: GPLv3
URL: https://github.com/OpenSCAP/foreman_openscap
Source0: http://rubygems.org/downloads/%{gem_name}-%{version}.gem

Requires: foreman >= 1.5.0

Requires: %{?scl_prefix}rubygem(deface)
Requires: %{?scl_prefix}rubygem(scaptimony) >= 0.3.0
Requires: %{?scl_prefix}rubygem(scaptimony) < 0.4.0
%if 0%{?fedora} > 18
Requires: %{?scl_prefix}ruby(release)
Requires: %{?scl_prefix}ruby(rubygems)
BuildRequires: %{?scl_prefix}ruby(release)
%else
Requires: %{?scl_prefix}ruby(abi) >= %{rubyabi}
Requires: %{?scl_prefix}rubygems
Requires: scap-security-guide
BuildRequires: %{?scl_prefix}ruby(abi) >= %{rubyabi}
%endif
BuildRequires: %{?scl_prefix}rubygems-devel
BuildRequires: %{?scl_prefix}rubygems
BuildRequires: foreman-assets >= 1.7.0
BuildRequires: %{?scl_prefix}rubygem(deface)
BuildRequires: %{?scl_prefix}rubygem(scaptimony) >= 0.3.0
BuildRequires: %{?scl_prefix}rubygem(scaptimony) < 0.4.0

BuildArch: noarch
Provides: %{?scl_prefix}rubygem(%{gem_name}) = %{version}
Provides: foreman-plugin-openscap

%description
Foreman plug-in for managing security compliance reports.


%package doc
Summary: Documentation for %{name}
Group: Documentation
Requires: %{?scl_prefix}%{pkg_name} = %{version}-%{release}
BuildArch: noarch

%description doc
Documentation for %{name}.

%prep
%{?scl:scl enable %{scl} "}
gem unpack %{SOURCE0}
%{?scl:"}

%setup -q -D -T -n  %{gem_name}-%{version}
mkdir -p .%{gem_dir}
%{?scl:scl enable %{scl} "}
gem install --local --install-dir .%{gem_dir} \
            --force %{SOURCE0} --no-rdoc --no-ri
%{?scl:"}

%build

%install
mkdir -p %{buildroot}%{gem_dir}
cp -a .%{gem_dir}/* \
        %{buildroot}%{gem_dir}/

mkdir -p %{buildroot}%{foreman_bundlerd_dir}

%foreman_bundlerd_file
%foreman_precompile_plugin

%files
%dir %{gem_instdir}
%{gem_libdir}
%{gem_instdir}/app
%{gem_instdir}/db
%{gem_instdir}/config
%exclude %{gem_cache}
%{gem_spec}
%{foreman_bundlerd_plugin}
%doc %{gem_instdir}/LICENSE
%{foreman_assets_plugin}

%exclude %{gem_instdir}/test

%files doc
%doc %{gem_instdir}/LICENSE
%doc %{gem_instdir}/README.md
%{gem_instdir}/Rakefile

%posttrans
# We need to run the db:migrate (because of SCAPtimony) after the install transaction
%foreman_db_migrate
/usr/sbin/foreman-rake db:seed  >/dev/null 2>&1 || :
/usr/sbin/foreman-rake apipie:cache  >/dev/null 2>&1 || :
%foreman_restart
exit 0

%changelog
* Tue May 26 2015 Mike McCune <mmccune@redhat.com> 0.3.2.10-1
- Fixes #10549 - show host name only if host exists (shlomi@ben-hanna.com)
- Introduce bulk upload, seed default content, rake tasks (shlomi@ben-
  hanna.com)

* Tue May 19 2015 Mike McCune <mmccune@redhat.com> 0.3.2.9-1
- Add Requires on the package scap-security-guide (bkearney@redhat.com)
- Merge pull request #97 from shlomizadok/policy_content_api
  (isimluk@fedoraproject.org)

* Tue May 05 2015 Mike McCune <mmccune@redhat.com> 0.3.2.8-1
- Fixes #10335 - support reports without host (mhulan@redhat.com)
- ref #10335 - Support reports w/o host on dashboard (shlomi@ben-hanna.com)

* Wed Apr 22 2015 Mike McCune <mmccune@redhat.com> 0.3.2.7-1
- bump version

* Wed Apr 22 2015 Mike McCune <mmccune@redhat.com> 0.3.2.6-1
- bump version (mmccune@redhat.com)

* Wed Apr 01 2015 Mike McCune <mmccune@redhat.com> 0.3.2.5-1
- increment version (mmccune@redhat.com)

* Wed Apr 01 2015 Mike McCune <mmccune@redhat.com> 0.3.2.4-1
- BZ1197114 - fixes search for host by name or by katello uuid
- update releasers file (jmontleo@redhat.com)

* Tue Mar 31 2015 Jason Montleon <jmontleo@redhat.com> 0.3.2.3-1
- increment version (jmontleo@redhat.com)
- enforce that host policies will also include hostgroup policies (shlomi@ben-
  hanna.com)

* Tue Mar 17 2015 Jason Montleon <jmontleo@redhat.com> 0.3.2.2-1
- update version (jmontleo@redhat.com)
- fixes #87 - ensure that either 'monthly' or 'weekly' are validated on edit
  (shlomi@ben-hanna.com)

* Mon Mar 02 2015 Jason Montleon <jmontleo@redhat.com> 0.3.2.1-1
- Merge tag 'v0.3.2' into SATELLITE-6.1.0 (jmontleo@redhat.com)
- Adds file location display to policy (shlomi@ben-hanna.com)
- create class param for port (shlomi@ben-hanna.com)
- foreman_openscap-0.3.2 (slukasik@redhat.com)
- create class param for port (shlomi@ben-hanna.com)
- Adds file location display to policy (shlomi@ben-hanna.com)
- fix hostgroup_ids= on policy (shlomi@ben-hanna.com)
- Setting location & organization from host should be by id (shlomi@ben-
  hanna.com)

* Fri Feb 20 2015 Jason Montleon <jmontleo@redhat.com> 0.3.1.3-1
- change version (jmontleo@redhat.com)

* Fri Feb 20 2015 Jason Montleon <jmontleo@redhat.com> 0.3.1.2-1
- Setting location & organization from host should be by id (shlomi@ben-
  hanna.com)

* Fri Feb 20 2015 Jason Montleon <jmontleo@redhat.com> 0.3.1.1-1
- new package built with tito

* Wed Jan 28 2015 Šimon Lukašík <slukasik@redhat.com> - 0.3.0-1
- new upstream release

* Fri Jan 23 2015 Marek Hulán <mhulan@redhat.com> - 0.2.1-1
- new upstream release

* Thu Dec 04 2014 Šimon Lukašík <slukasik@redhat.com> - 0.2.0-1
- new upstream release

* Thu Oct 23 2014 Šimon Lukašík <slukasik@redhat.com> - 0.1.0-1
- rebuilt

* Mon Jul 28 2014 Šimon Lukašík <slukasik@redhat.com> - 0.0.1-1
- Initial package
